@@ -17,6 +17,8 @@ from pycatia.types import cat_variant
 class Publications(Collection):
     """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
 
                 | System.IUnknown
@@ -39,6 +41,8 @@ class Publications(Collection):
     def add(self, i_public_name: str) -> Publication:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Func Add(CATBSTR iPublicName) As Publication
                 | 
@@ -68,6 +72,8 @@ class Publications(Collection):
     def item(self, i_identifier: cat_variant) -> Publication:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Func Item(CATVariant iIdentifier) As Publication
                 | 
@@ -96,6 +102,8 @@ class Publications(Collection):
     def remove(self, i_identifier: str) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub Remove(CATBSTR iIdentifier)
                 | 
@@ -121,6 +129,8 @@ class Publications(Collection):
     def set_direct(self, i_identifier: cat_variant, i_pointed: 'Reference') -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub SetDirect(CATVariant iIdentifier,
                 | Reference iPointed)
@@ -164,12 +174,14 @@ class Publications(Collection):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def set_relay(self, i_identifier: cat_variant, i_relayer: 'Publications', i_name_in_relay: cat_variant) -> None:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub SetRelay(CATVariant iIdentifier,
                 | Publications iRelayer,
@@ -215,7 +227,7 @@ class Publications(Collection):
         # # End Function
         # # """
 
-        # # system_service = SystemService(self.application.SystemService)
+        # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
